#
# spec file for package python-nautilus
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define build_doc 0

Name:           python-nautilus
%define _name   nautilus-python
Version:        1.1
Release:        17.1
Summary:        Python bindings for Nautilus
License:        GPL-2.0+
Group:          Development/Libraries/Python
Url:            http://git.gnome.org/cgit/nautilus-python/
Source:         http://download.gnome.org/sources/nautilus-python/1.1/%{_name}-%{version}.tar.bz2
%if %{build_doc}
BuildRequires:  gtk-doc
%endif
BuildRequires:  libtool
BuildRequires:  python-devel
BuildRequires:  pkgconfig(libnautilus-extension)
BuildRequires:  pkgconfig(pygobject-3.0)
Requires:       python-gobject
# we can't have automatic typelib() Requires here: it's C code: PyImport_ImportModule("gi.repository.Nautilus")
Requires:       typelib(Nautilus)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains bindings to write Nautilus extensions with Python.
It allows writing menu, property pages and column providers extensions,
so that Nautilus functionality can be easily extended.

%package devel
Summary:        Python bindings for Nautilus - Development Files
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description devel
Development files needed for writing Nautilus Python extensions
This package contains bindings to write Nautilus extensions with Python.
It allows writing menu, property pages and column providers extensions,
so that Nautilus functionality can be easily extended.

%prep
%setup -q -n %{_name}-%{version}

%build
autoreconf -fi -I m4
%configure --disable-static \
%if %{build_doc}
        --enable-gtk-doc
%else
        --disable-gtk-doc
%endif
make %{?jobs:-j%jobs}

%install
%makeinstall
# New dir where python extensions get installed. It's not created by make
# install (bgo#638890).
test ! -d %{buildroot}%{_datadir}/nautilus-python/extensions
mkdir -p %{buildroot}%{_datadir}/nautilus-python/extensions
find %{buildroot} -type f -name "*.la" -delete -print

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_libdir}/nautilus/extensions-3.0/libnautilus-python.so
%dir %{_datadir}/nautilus-python
%dir %{_datadir}/nautilus-python/extensions

%files devel
%defattr(-,root,root)
%{_datadir}/doc/nautilus-python/
%if %{build_doc}
%{_datadir}/gtk-doc/html/nautilus-python/
%endif
%{_libdir}/pkgconfig/nautilus-python.pc

%changelog
* Wed May  9 2012 vuntz@opensuse.org
- Explicitly add missing typelib(Nautilus) Requires: we can't use
  the automatic typelib() Requires generator since this python
  module is written in C.
* Fri Dec  2 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 1.1:
  + Added pygobject3 compatibility, and retained pygobject 2.28.x
    compatibility.
  + Bugs fixed: bgo#660290, bgo#660288, bgo#660287, bgo#660286,
    bgo#660283, bgo#653169.
- Drop patches that have been merged upstream:
  + python-nautilus-fix-path-in-pc.patch
  + python-nautilus-fix-warnings.patch
  + python-nautilus-no-extension-on-failure.patch
  + python-nautilus-pygobject-3.0.patch
* Wed Sep 28 2011 vuntz@opensuse.org
- Port to pygobject 3.0:
  + Add nautilus-python-pygobject-3.0.patch: do the port :-)
  + Change pkgconfig(pygobject-2.0) BuildRequires to
    pkgconfig(pygobject-3.0).
  + Add call to autoreconf, needed for the patch.
- Use a build_doc macro to decide whether to build the
  documentation. It controls the following:
  + Use of gtk-doc BuildRequires.
  + Use of --disable-gtk-doc or --enable-gtk-doc option passed to
    configure.
- Set build_doc macro to 0 as the documentation build currently
  requires the old pygobject.
- Add python-nautilus-fix-warnings.patch: fix various warnings in
  the build.
- Add python-nautilus-no-extension-on-failure.patch: do not load
  extensions on initialization failures.
* Wed Jun 22 2011 malcolmlewis@opensuse.org
- Fix /usr/share/nautilus-python directories not owned by a
  package.
- Update spec file Licence field from GPLv2+ to GPL-2.0+ to
  conform with spdx.org identifier.
* Fri Jun 17 2011 vuntz@opensuse.org
- Add python-nautilus-fix-path-in-pc.patch to fix the pkg-config
  file to refer to the right extension directory, now that it
  changed.
* Fri May 27 2011 vuntz@opensuse.org
- Update dependencies after move to gobject introspection:
  + Remove python-gnome-devel, python-gtk-devel BuildRequires,
    python-gtk Requires from main package, and python-gtk-devel
    Requires from devel subpackage.
  + Add pkgconfig(pygobject-2.0) BuildRequires and python-gobject
    Requires.
- Change nautilus-devel BuildRequires to
  pkgconfig(libnautilus-extension).
- Drop unneeded python-gobject2-doc BuildRequires.
- Fix license tag: the code is GPLv2+ (and not LGPLv2+).
- Stop creating %%{_libdir}/nautilus/extensions-2.0/python directory
  as extensions there are not considered anymore.
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 1.0:
  + Use the gobject instrospection dynamic bindings, breaks
    compatibility for existing extensions.
  + For Nautilus3, the get_toolbar_items methods have been removed.
  + No longer look in the old ~/.nautilus/python-extensions or
    /usr/lib/nautilus/extensions2.0/python folders for extensions.
    Now look in ~/.local/share/nautilus-python/extensions or
    $XDG_DATA_DIR/nautilus-python/extensions.
  + Updated the gtk-doc documentation and examples to work with new
    dynamic bindings.
* Mon May  2 2011 dimstar@opensuse.org
- Update to version 0.7.3:
  + Use PyCapsule_Import for pygobject as well as pygtk
  + bgo#644399: in the property page example plugin, get the md5sum
    of the file contents, not the file name
  + Removed extraneous .cvsignore files
  + Fixed the update-file-info-async example plugin.
* Mon Mar 21 2011 dimstar@opensuse.org
- Update to version 0.7.2:
  + Fix to get the PyCapsule patch to work even if there is no
    PyCapsule object set up for pygtk
- Changes from version 0.7.1:
  + bgo#619440: Fixed AM_CHECK_PYTHON_LIBS usage of test
  + Cleaned up the docs Makefile.am to make it more consistent
  + Fix some python3 syntax issues in the python.m4 script
  + bgo#633171: Add python 2.7 support.
* Fri Jan  7 2011 vuntz@opensuse.org
- Create and own %%{_datadir}/nautilus-python/extensions since
  extensions can be installed there now.
* Sun Aug  8 2010 vuntz@opensuse.org
- Pass --enable-gtk-doc to configure, and add gtk-doc and
  python-gobject2-doc BuildRequires to build the API docs.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.7.0:
  + Added methods:
  - nautilus.InfoProvider.update_file_info_full
  - nautilus.InfoProvider.update_complete_invoke
  - nautilus.InfoProvider.cancel_update
  - nautilus.MenuProvider.get_file_items_full
  - nautilus.MenuProvider.get_background_items_full
  - nautilus.MenuProvider.get_toolbar_items_full
  - nautilus.MenuProvider.emit_items_updated_signal
  + Added complete gtk-doc documentation: tutorial and reference.
    Enable by adding the --enable-gtk-doc argument to ./configure
    or ./autogen.sh
  + Updated the autogen.sh file so it is not a copied-over obsolete
    version of gnome-autogen.sh, but a shell that calls the user's
    installed gnome-autogen.sh.
  + Removed obsolete .spec file
  + Removed obsolete examples/documentation.py file
  + Added an example plugin for the LocationWidgetProvider
  + Look for python plugins in
    $XDG_DATA_DIR/nautilus-python/extensions.
    This includes ~/.local/share and /usr/share (or whatever
    $XDG_DATA_DIR is set to).
* Tue Jan 19 2010 vuntz@opensuse.org
- Update to version 0.6.1:
  + Look for libpython2.6.so.1.0 instead of libpython2.6.so, the
    latter is general available from -devel packages only.
  + Re-added the missing spec and pc files
  + Free pygobject data directly after using file objects. Stops
    seg faults from occurring when nautilus wants to free pygobject
    data after Py_Finalize() is called.
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 0.6.0:
  + Remove eel dependency
  + Sanitize python search path
  + Remove gnomevfs dependency and unused code
  + Load python from lib64 in 64 bit multilib distributions
  + Fix segfault when a plugin doesn't implement the __init__
    method
  + Added the can_write, get_mount, get_file_type, get_location,
    and get_parent_location methods to the NautilusFileInfo object
  + Added the NautilusMenu.get_items method
  + Updated some example plugins
  + Bug fix for some PyThreadState_New segmentation faults
  + Use the nautilus prefix by default for distfiles, rather than
    /usr
  + Require nautilus-2.22 and pygobject-2.16 now that we support
    GIO
- Drop python-nautilus-no-libeel.patch: fixed upstream.
- Drop python-nautilus-no-gnomevfs.patch: fixed upstream.
- Drop python-nautilus-autoreconf-m4.patch: not needed anymore,
  since we can remove the autoreconf call now.
* Sun Jun 14 2009 vuntz@novell.com
- Clean up package for Contrib.
